pub enum SampleFormat {
    F32(Endianness),
    F64(Endianness),
    I32(Endianness),
    I16(Endianness),
    U32(Endianness),
    U16(Endianness),
    I8,
    U8,
}
Sample format.

The sample format indicates the width and type (floating point or integer) of the numbers used to represent the signal samples.

Variants



F32(Endianness)

32-bit IEEE 754 floating point.



F64(Endianness)

64-bit IEEE 754 floating point.



I32(Endianness)

32-bit signed integer.



I16(Endianness)

16-bit signed integer.



U32(Endianness)

32-bit unsigned integer.



U16(Endianness)

16-bit unsigned integer.



I8

8-bit signed integer.



U8

8-bit unsigned integer.